@@ -17,11 +17,10 @@ You should have received a copy of the GNU General Public License
 along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-__version__ = "0.2.14"
+__version__ = "0.2.15"
 from atoms import *
 from expressions.variables import Variable, Semidef
-from expressions.constants import Parameter
-from expressions.constants import Constant
+from expressions.constants import Parameter, CallbackParam, Constant
 from problems.problem import Problem
 from problems.objective import Maximize, Minimize
 import interface.numpy_wrapper
