@@ -58,6 +58,8 @@ atoms = [
             Constant([[0.25, 2.25],[13.75, 0]])),
         (inv_pos, (2, 2), [ [[1,2],[3,4]] ],
             Constant([[1,1.0/2],[1.0/3,1.0/4]])),
+        (lambda x: (x + Constant(0))**-1, (2, 2), [ [[1,2],[3,4]] ],
+            Constant([[1,1.0/2],[1.0/3,1.0/4]])),
         (kl_div, (1, 1), [math.e, 1], Constant([1])),
         (kl_div, (1, 1), [math.e, math.e], Constant([0])),
         (lambda_max, (1, 1), [ [[2,0],[0,1]] ], Constant([2])),
@@ -118,6 +120,7 @@ atoms = [
         (lambda x: norm(x, 2), (1, 1), [ [[2,0],[0,1]] ], Constant([2])),
         (lambda x: norm(x, 2), (1, 1), [ [[3,4,5],[6,7,8],[9,10,11]] ], Constant([22.368559552680377])),
         (square, (2, 2), [ [[-5,2],[-3,1]] ], Constant([[25,4],[9,1]])),
+        (lambda x: (x + Constant(0))**2, (2, 2), [ [[-5,2],[-3,1]] ], Constant([[25,4],[9,1]])),
         (sum_squares, (1, 1), [ [[-1, 2],[3, -4]] ], Constant([30])),
         (trace, (1, 1), [ [[3,4,5],[6,7,8],[9,10,11]] ], Constant([3 + 7 + 11])),
         (trace, (1, 1), [ [[-5,2],[-3,1]]], Constant([-5 + 1])),
@@ -153,6 +156,7 @@ atoms = [
         # #(pow_rat(4,2,4), 2),
         # #(pow_rat(16,3,4),8),
         (sqrt, (2, 2), [ [[2,4],[16,1]] ], Constant([[1.414213562373095,2],[4,1]])),
+        (lambda x: (x + Constant(0))**0.5, (2, 2), [ [[2,4],[16,1]] ], Constant([[1.414213562373095,2],[4,1]])),
     ], Maximize),
 ]
 
